#
# spec file for package gap-help
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-help
Version:        4.0
Release:        1.4
Summary:        GAP: Hertweck-Luthar-Passi method
License:        GPL-2.0-only
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/HeLP/
Source:         https://github.com/gap-packages/HeLP/releases/download/v%version/HeLP-%version.tar.gz
BuildRequires:  gap-rpm-devel
BuildRequires:  xz
BuildArch:      noarch
# 4ti2: to get /usr/bin/zsolve
Requires:       4ti2 >= 1.6.5
Requires:       gap-4ti2interface >= 2015.04.29
Requires:       gap-atlasrep >= 1.5
Requires:       gap-core >= 4.8.2
Requires:       gap-ctbllib >= 1.2.2
Requires:       gap-io >= 4.2
Requires:       gap-normalizinterface >= 0.9.6

%description
HeLP is a package to compute constraints on partial augmentations of
torsion units in integral group rings using a method developed by
Luthar, Passi and Hertweck. The package can be employed to verify the
Zassenhaus Conjecture and the Prime Graph Question for finite groups,
once characters are known. It uses an interface to the software
package 4ti2 to solve integral linear inequalities.

%prep
%autosetup -n HeLP-%version

%build

%install
%gappkg_simple_install

%files -f %name.files

%changelog
* Mon Mar  4 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 4.0
  * Two new global functions: HeLP_SP and HeLP_KP to study the
    Spectrum Problem and the Kimmerle Problem and their companion
    functions HeLP_AllOrdersSP and HeLP_AllOrdersKP
  * More theoretical results are taken into account when the
    system to solve is generated, namely more partial
    augmentations are assumed to be 0 a priori. This includes
    three results: Berman-Higman (in the general form that the
    coefficient at a central element is 0, if the unit is not
    that element), Hertweck's Proposition 2 from [Hertweck08] (if
    a unit u has smaller order modulo a normal p-subgroup,
    elements with non-zero partial augmentations must have same
    p-power order as u) and Hertweck's p-adic criterion (units
    which map tp 1 modulo a normal p-subgroup are p-adically
    conjugate to elements in G and hence the p-part of any
    element with non-zero partial augmentation is unique up to
    conjugacy in G)
  * Three new minor global functions: HeLP_UnitSatisfiesKP to
    check manually for KP and given partial augmentaion;
    HeLP_IsOneModuloN to see if a unit is mapped to the identity
    modulo a normal subgroup N; HeLP_ForgetUnderlyingGroup to
    obtain same table without group structure. This way the new
    theretical restictions do not apply and one can obtain the
    results as in older versions
* Wed Dec 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.5
  * Janitorial changes only
* Sun Dec 24 2017 jengelh@inai.de
- Update to new upstream release 3.3
  * Line 542 in "expamples/examples.g" corrected
  * testfile in PackageInfo.g changed to "tst/testall.g"
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 3.1
  * New function HeLP_AutomorphismOrbits, HeLP_IsZCKnown,
    HeLP_WithGivenOrderAllTables, HeLP_WithGivenOrderAndPAAllTables,
    HeLP_WriteTrivialSolution.
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 3.0
  * Normaliz is included as a possible solver.
  * Functions included to switch between the solvers. For normaliz,
  a function is included to influence whether normaliz computes
  vertices of polyhedra.
* Fri Mar 11 2016 jengelh@inai.de
- Initial package (version 2.2) for build.opensuse.org
